@@ -77,11 +77,10 @@ parseCaptureOptions =
 runCapture
   :: ( MonadMask m
      , MonadUnliftIO m
-     , MonadResource m
+     , MonadAWS m
      , MonadLogger m
      , MonadReader env m
      , HasAwsScope env
-     , HasAwsEnv env
      , HasConfig env
      , HasDirectoryOption env
      )
