@@ -16,38 +16,40 @@ spec :: Spec
 spec = do
   describe "sortStackSpecs" $ do
     it "orders dependencies before dependents" $ do
-      let
-        specs =
-          [ toSpec "app" ["roles", "iam", "networking"]
-          , toSpec "roles" ["iam"]
-          , toSpec "iam" []
-          , toSpec "networking" []
-          ]
+      let specs =
+            [ toSpec "app" ["roles", "iam", "networking"]
+            , toSpec "roles" ["iam"]
+            , toSpec "iam" []
+            , toSpec "networking" []
+            ]
 
       map specName (sortStackSpecs specs)
         `shouldBe` ["iam", "roles", "networking", "app"]
 
 toSpec :: Text -> [Text] -> StackSpec
-toSpec name depends = flip runReader emptyConfig
-  $ buildStackSpec "." specPath specBody
+toSpec name depends =
+  flip runReader emptyConfig
+    $ buildStackSpec "." specPath specBody
  where
   stackName = StackName name
   specPath = stackSpecPath scope stackName "a/b.yaml"
-  specBody = StackSpecYaml
-    { ssyDescription = Nothing
-    , ssyDepends = Just $ map StackName depends
-    , ssyActions = Nothing
-    , ssyTemplate = ""
-    , ssyParameters = Nothing
-    , ssyCapabilities = Nothing
-    , ssyTags = Nothing
-    }
+  specBody =
+    StackSpecYaml
+      { ssyDescription = Nothing
+      , ssyDepends = Just $ map StackName depends
+      , ssyActions = Nothing
+      , ssyTemplate = ""
+      , ssyParameters = Nothing
+      , ssyCapabilities = Nothing
+      , ssyTags = Nothing
+      }
 
-  scope = AwsScope
-    { awsAccountId = AccountId ""
-    , awsAccountName = ""
-    , awsRegion = Region' ""
-    }
+  scope =
+    AwsScope
+      { awsAccountId = AccountId ""
+      , awsAccountName = ""
+      , awsRegion = Region' ""
+      }
 
 specName :: StackSpec -> Text
 specName = unStackName . stackSpecStackName
